@@ -15,7 +15,7 @@ if __name__ == "__main__":
     from projects import *
     from utils import *
 
-    import lims2
+    import lims2 as lims
     import mtrain
 
     import data_getters as dg
@@ -24,7 +24,7 @@ else:
     from .projects import *
     from .utils import *
 
-    from . import lims2
+    from . import lims2 as lims
     from . import mtrain
 
     from . import data_getters as dg
@@ -89,14 +89,15 @@ class Session:
 
         path = pathlib.Path(path)
 
-        self.folder = folder(path)
+        np_folder = folder(path)
 
-        if not self.folder and is_lims_path(path):
-            self.folder = folder_from_lims_id(path)
+        if not np_folder:
+            np_folder = folder_from_lims_id(path)
 
-        if self.folder is None:
-            raise SessionError(f"{path} does not contain a valid session folder string")
+        if np_folder is None:
+            raise SessionError(f"{path} does not contain a valid lims session id or session folder string")
 
+        self.folder = np_folder
         self.id = self.folder.split("_")[0]
 
     @property
@@ -116,7 +117,7 @@ class Session:
         """
         if not hasattr(self, "_lims"):
             try:
-                self._lims = lims2.SessionInfo(self.id)
+                self._lims = lims.SessionInfo(self.id)
             except ValueError:
                 self._lims = {}
         return self._lims
@@ -125,7 +126,7 @@ class Session:
     def mouse(self) -> str | dict[str, Any]:
         if not hasattr(self, "_mouse"):
             try:
-                self._mouse = lims2.MouseInfo(self.folder.split("_")[1])
+                self._mouse = lims.MouseInfo(self.folder.split("_")[1])
             except ValueError:
                 self._mouse = {}
         return self._mouse
